import MY_CONSTANTS from '@/lib/constants-standards.js'

type Contact = {
    name: string
    link: string
    mail: string
    phone: string
    contactform: string
}
type LinkItem = {
    name: string
    link: string
}

type InfoboxOptions = {
    productOwner: Contact
    developer: Contact
    contact: Contact
    supportInfo: LinkItem[]
    artefacts: LinkItem[]
    combinedStandards: LinkItem[]
    lastUpdate: string
}


//  Converts an ISO dtae into long German date format
function convertIsoDateToLongDate(theDate: string) {
    const monthNames = ['Januar', 'Februar', 'März', 'April', 'Mai', 'Juni', 'Juli', 'August', 'September', 'Oktober', 'November', 'Dezember']

    // Check format
    const regexp = /\d{4}-[01]\d-[0-3]\d/
    if (!regexp.test(theDate)) {
        return '#INVALID'
    }

    // Evaluate string content, e.-g. 2023-09-15
    const year = theDate.substring(0, 4)
    const month = parseInt(theDate.substring(5, 7))
    const dayInMonth = parseInt(theDate.substring(8))

    return dayInMonth + '. ' + monthNames[month - 1] + ' ' + year
}

export function InfoBoxes({
    productOwner,
    developer,
    contact,
    supportInfo,
    artefacts,
    combinedStandards,
    lastUpdate,
}: InfoboxOptions) {
    return (
        <div>
            {lastUpdate && (
                <div className="w-80 border-2 mb-4 rounded-md">
                    <div className={`${MY_CONSTANTS.BG_COLORS.DEFAULT} p-1 font-bold`}>Letzte Aktualisierung</div>
                    <div className="text-sm p-1">
                        <div className="flex">
                            <div className={`${MY_CONSTANTS.INFOBOX_1ST_COLUMN_WIDTH} font-semibold`}>Datum</div>
                            <div>{convertIsoDateToLongDate(lastUpdate)}</div>
                        </div>
                    </div>
                </div>

            )}
        </div>
    )
}
